@@ -56,7 +56,8 @@ def repo(tk1):
 
 @buildpan.command()
 @click.option('--token', '-e', default="dev", prompt='Enter token ', help='Shows all the repo in the account')
-def selectrepo(token):
+@click.option('--username', '-e', default="dev", prompt='Enter username ', help='Enter the github username')
+def selectrepo(token,username):
     '''Select the repo in the account '''
     """
     param : token is the argument which is a aceess token for getting access to the
@@ -74,8 +75,8 @@ def selectrepo(token):
      print(i," ",repo.name)
     i=i+1
     name=input("Enter the repo name")
-    repo=g.get_repo("AkashAi7/"+name)
-    reponame="AkashAi7/"+name
+    repo=g.get_repo(username+"/"+name)
+    reponame=username+"/"+name
     print(reponame)
     content=repo.get_contents("")
     for file in content:
